@@ -55,8 +55,7 @@ Message::Passing::Input::FileTail - File tailing input
 
 =head1 SYNOPSIS
 
-    logstash --input FileTail --input_options '{"filename": "/var/log/foo.log"} --output STDOUT
-    {"foo": "bar"}
+    message-passing --input FileTail --input_options '{"filename": "/var/log/foo.log"} --output STDOUT
     {"foo":"bar"}
 
 =head1 DESCRIPTION
@@ -65,10 +64,6 @@ Message::Passing::Input::FileTail - File tailing input
 
 L<Message::Passing>
 
-=head1 AUTHOR
-
-Tomas (t0m) Doran <bobtfish@bobtfish.net>
-
 =head1 SPONSORSHIP
 
 This module exists due to the wonderful people at Suretec Systems Ltd.
@@ -77,16 +72,9 @@ VoIP division called SureVoIP <http://www.surevoip.co.uk/> for use with
 the SureVoIP API - 
 <http://www.surevoip.co.uk/support/wiki/api_documentation>
 
-=head1 COPYRIGHT
+=head1 AUTHOR, COPYRIGHT AND LICENSE
 
-Copyright Suretec Systems 2012.
-
-Logstash (upon which many ideas for this project is based, but
-which we do not reuse any code from) is copyright 2010 Jorden Sissel.
-
-=head1 LICENSE
-
-XX - TODO
+See L<Message::Passing>.
 
 =cut
 
