@@ -29,7 +29,7 @@ Message::Passing::Input::STDIN - STDIN input
 
 =head1 SYNOPSIS
 
-    logstash --input STDIN --output STDOUT
+    message-passing --input STDIN --output STDOUT
     {"foo": "bar"}
     {"foo":"bar"}
 
@@ -39,10 +39,6 @@ Message::Passing::Input::STDIN - STDIN input
 
 L<Message::Passing>
 
-=head1 AUTHOR
-
-Tomas (t0m) Doran <bobtfish@bobtfish.net>
-
 =head1 SPONSORSHIP
 
 This module exists due to the wonderful people at Suretec Systems Ltd.
@@ -51,15 +47,8 @@ VoIP division called SureVoIP <http://www.surevoip.co.uk/> for use with
 the SureVoIP API - 
 <http://www.surevoip.co.uk/support/wiki/api_documentation>
 
-=head1 COPYRIGHT
+=head1 AUTHOR, COPYRIGHT AND LICENSE
 
-Copyright Suretec Systems 2012.
-
-Logstash (upon which many ideas for this project is based, but
-which we do not reuse any code from) is copyright 2010 Jorden Sissel.
-
-=head1 LICENSE
-
-XX - TODO
+See L<Message::Passing>.
 
 =cut
